/*
 * Vector2D.cpp
 * 
 * Copyright (C) 2008 Matthias Schiffer <matthias@gamezock.de>
 * 
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "Vector2D.h"
#include <cmath>

namespace ZoomEdit {
namespace Math {

float Vector2D::lengthSq() const {
  return x*x + y*y;
}

float Vector2D::length() const {
  return std::sqrt(lengthSq());
}

Vector2D Vector2D::operator+(const Vector2D &v) const {
  return Vector2D(x + v.x, y + v.y);
}

Vector2D Vector2D::operator-(const Vector2D &v) const {
  return Vector2D(x - v.x, y - v.y);
}

float Vector2D::operator*(const Vector2D &v) const {
  return (x*v.x + y*v.y);
}

Vector2D Vector2D::operator*(float f) const {
  return Vector2D(x*f, y*f);
}

Vector2D Vector2D::operator/(float f) const {
  return Vector2D(x/f, y/f);
}

Vector2D& Vector2D::operator+=(const Vector2D &v) {
  x += v.x;
  y += v.y;
  
  return *this;
}

Vector2D& Vector2D::operator-=(const Vector2D &v) {
  x -= v.x;
  y -= v.y;
  
  return *this;
}

Vector2D& Vector2D::operator*=(float f) {
  x *= f;
  y *= f;
  
  return *this;
}

Vector2D& Vector2D::operator/=(float f) {
  x /= f;
  y /= f;
  
  return *this;
}

}
}
